"""
Django settings for server project.

Generated by 'django-admin startproject' using Django 3.2.15.

For more information on this file, see
https://docs.djangoproject.com/en/3.2/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.2/ref/settings/
"""

from pathlib import Path

from config import orc_config


# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.2/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = orc_config.ORC_SECRET_KEY

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = orc_config.ORC_DEBUG

ALLOWED_HOSTS = orc_config.ORC_ALLOWED_HOSTS

# Don't use trailing slash in urls.
# The APPEND_SLASH setting is only used if CommonMiddleware is installed.
APPEND_SLASH = False

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'rest_framework',
    'drf_yasg',
    'django_pam',
    'orchestrator',
]

AUTH_USER_MODEL = 'orchestrator.User'

LOGIN_REDIRECT_URL = '/admin'

AUTHENTICATION_BACKENDS = [
    'django_pam.auth.backends.PAMBackend',
    'django.contrib.auth.backends.ModelBackend',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'orchestrator.middleware.security.check_https_middleware',
    'orchestrator.middleware.openstack.OpenStackAuthMiddleware',
]

ROOT_URLCONF = 'server.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'server.wsgi.application'


# Database
# https://docs.djangoproject.com/en/3.2/ref/settings/#databases

# DATABASES = {
#     'default': {
#         'ENGINE': 'django.db.backends.sqlite3',
#         'NAME': BASE_DIR / 'db.sqlite3',
#     },
#     # 'default': {
#     #     'ENGINE': 'django.db.backends.postgresql_psycopg2',
#     #     'NAME': 'myproject',
#     #     'USER': 'myprojectuser',
#     #     'PASSWORD': 'password',
#     #     'HOST': 'localhost',
#     #     'PORT': '',
#     # }
# }


# Password validation
# https://docs.djangoproject.com/en/3.2/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator', },
    {'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator', },
    {'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator', },
    {'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator', },
]


# Internationalization
# https://docs.djangoproject.com/en/3.2/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'Europe/Moscow'

USE_I18N = True

USE_L10N = True

USE_TZ = False


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.2/howto/static-files/

STATIC_URL = '/static/'

# Default primary key field type
# https://docs.djangoproject.com/en/3.2/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

ALLOW_HTTPS_ONLY = orc_config.ORC_HTTPS_ONLY

# Logging params
BASE_LOGDIR = "/var/log/termidesk"
ORC_LOGFILE = "orchestrator.log"
LOGLEVEL = orc_config.ORC_LOGLEVEL

_verbose_format = '[%(asctime)s] [%(process)s] [%(threadName)s] [%(levelname)s] [%(name)s] %(message)s'
_simple_format = '%(levelname)s %(asctime)s %(name)s %(message)s'
LOGGING = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': {
        'verbose': {
            'format': _verbose_format,
            'datefmt': '%Y-%m-%d %H:%M:%S %z'
        },
        'simple': {
            'format': _simple_format
        },
    },
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse',
        }
    },
    'handlers': {
        'null': {
            'level': 'DEBUG',
            'class': 'logging.NullHandler',
        },
        'console': {
            'level': 'INFO',
            'class': 'logging.StreamHandler',
            'formatter': 'verbose'
        },
        'file_orchestrator': {
            'level': 'DEBUG',
            'class': 'logging.handlers.RotatingFileHandler',
            'formatter': 'verbose',
            'filename': BASE_LOGDIR + '/' + ORC_LOGFILE,
            'mode': 'a',
            'backupCount': 3,
            'encoding': 'utf-8'
        },
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler',
            'filters': ['require_debug_false']
        },
    },
    'loggers': {
        'django': {
            'handlers': ['null'],
            'propagate': True,
            'level': 'INFO',
        },
        'django.request': {
            'handlers': ['file_orchestrator'],
            'level': 'ERROR',
            'propagate': False,
        },
        'server': {
            'handlers': ['file_orchestrator'],
            'level': LOGLEVEL,
            'propagate': False,
        },
        'orchestrator': {
            'handlers': ['file_orchestrator'],
            'level': LOGLEVEL,
            'propagate': False,
        },
        '': {
            'handlers': ['file_orchestrator'],
            'level': LOGLEVEL,
            'propagate': False,
        }
    }
}
